@@ -949,7 +949,7 @@ public class KmerCompressor {
 	/** Print messages to this stream */
 	protected static PrintStream outstream=System.err;
 	/** Permission to overwrite existing files */
-	public static boolean overwrite=false;
+	public static boolean overwrite=true;
 	/** Permission to append to existing files */
 	public static boolean append=false;
 	/** Print speed statistics upon completion */
