@@ -7,7 +7,6 @@ import java.util.Arrays;
 import java.util.BitSet;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Locale;
 
 import fileIO.ByteFile;
 import fileIO.ByteFile1;
@@ -119,7 +118,7 @@ public class DemuxByName {
 				perheader=Parse.parseBoolean(b);
 			}else if(a.equals("delimiter")){
 				delimiter=Parse.parseSymbol(b);
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
@@ -473,8 +472,8 @@ public class DemuxByName {
 		double bpnano=basesProcessed/(double)(t.elapsed);
 		
 		outstream.println("Time:               "+t);
-		outstream.println("Reads Processed:    "+readsProcessed+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", rpnano*1000000));
-		outstream.println("Bases Processed:    "+basesProcessed+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", bpnano*1000));
+		outstream.println("Reads Processed:    "+readsProcessed+" \t"+Tools.format("%.2fk reads/sec", rpnano*1000000));
+		outstream.println("Bases Processed:    "+basesProcessed+" \t"+Tools.format("%.2fm bases/sec", bpnano*1000));
 		outstream.println("Reads Out:    "+readsOut);
 		outstream.println("Bases Out:    "+basesOut);
 		
