@@ -9,7 +9,6 @@ import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedHashSet;
-import java.util.Locale;
 import java.util.Map.Entry;
 import java.util.regex.Pattern;
 
@@ -22,8 +21,6 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
-import fileIO.TextFile;
-import hiseq.IlluminaHeaderParser1;
 import hiseq.IlluminaHeaderParser2;
 import shared.Parse;
 import shared.Parser;
@@ -304,7 +301,7 @@ public class DemuxByName2 {
 				//Flag was captured by BufferedMultiCros; do nothing
 			}else if(parser.parse(arg, a, b)){
 				//Flag was captured by the parser; do nothing
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
@@ -733,8 +730,8 @@ public class DemuxByName2 {
 		double bpnano=basesProcessed/(double)(t.elapsed);
 		
 		outstream.println("Time:               "+t);
-		outstream.println("Reads Processed:    "+readsProcessed+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", rpnano*1000000));
-		outstream.println("Bases Processed:    "+basesProcessed+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", bpnano*1000));
+		outstream.println("Reads Processed:    "+readsProcessed+" \t"+Tools.format("%.2fk reads/sec", rpnano*1000000));
+		outstream.println("Bases Processed:    "+basesProcessed+" \t"+Tools.format("%.2fm bases/sec", bpnano*1000));
 		outstream.println("Reads Out:          "+readsOut);
 		outstream.println("Bases Out:          "+basesOut);
 		outstream.println("Yield:              "+String.format("%.5f", readsOut*1.0/readsProcessed));
