@@ -6,6 +6,7 @@ import java.util.Arrays;
 import java.util.HashSet;
 
 import align2.QualityTools;
+import aligner.SideChannel3;
 import bloom.KCountArray;
 import bloom.KmerCountAbstract;
 import cardinality.CardinalityTracker;
@@ -797,6 +798,10 @@ public class Parser {
 			FASTQ.FLIP_R2=Parse.parseBoolean(b);
 		}
 		
+		else if(a.equalsIgnoreCase("sidechannelstats")){
+			SideChannel3.TRACK_STATS=Parse.parseBoolean(b);
+		}
+		
 //		else if(a.equalsIgnoreCase("sortserial")){
 //			KmerCountAbstract.SORT_SERIAL=Parse.parseBoolean(b);
 //		}
