@@ -10,6 +10,8 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextStreamWriter;
+import json.JsonObject;
+import json.JsonParser;
 import kmer.AbstractKmerTableSet;
 import server.ServerTools;
 import shared.KillSwitch;
@@ -306,128 +308,7 @@ public class SendSketch extends SketchObject {
 		else if(refNames!=null){processRefMode(t);}
 		else{processRemote(t);}
 	}
-
-	@Deprecated
-	private void processRemote_old(Timer t){
-		Timer ttotal=new Timer();
-		
-		t.start();
-		inSketches=tool.loadSketches_MT(defaultParams, in);
-		final int numLoaded=(inSketches.size());
-		if(numLoaded>1 && defaultParams.mode==PER_FILE){
-			inSketches.sort(SketchIdComparator.comparator);//Otherwise they come out disordered
-		}
-		
-		t.stop();
-		if(!silent){outstream.println("Loaded "+numLoaded+" sketch"+(numLoaded==1 ? "" : "es")+" in "+t);}
-		assert(numLoaded<=MAX_ALLOWED_SKETCHES) : "\nSendSketch is configured to send at most "+MAX_ALLOWED_SKETCHES+" to prevent overwhelming the server.\n"
-				+ "If you need to compare more than that, please use CompareSketch locally instead.\n"
-				+ "References can be downloaded at http://portal.nersc.gov/dna/microbial/assembly/bushnell/\n";
-		t.start();
-//		outstream.println(inSketches.get(0));
-		
-		if(numLoaded>4000){
-			SEND_BUFFER_MAX_BYTES*=4;
-			SEND_BUFFER_MAX_SKETCHES*=4;
-		}else if(numLoaded>1000){
-			SEND_BUFFER_MAX_BYTES*=2;
-			SEND_BUFFER_MAX_SKETCHES*=2;
-		}
-		
-		if(ffout==null){return;}
-		TextStreamWriter tsw=new TextStreamWriter(ffout);
-		tsw.start();
-		if(defaultParams.format==DisplayParams.FORMAT_QUERY_REF_ANI || defaultParams.format==DisplayParams.FORMAT_CONSTELLATION){tsw.println(defaultParams.header());}
-		
-		ByteBuilder bb=new ByteBuilder();
-		
-		int cntr=0;
-		int chunks=0;
-		for(Sketch sk : inSketches){
-			
-			if(sk.taxID<1 || sk.taxID>=minFakeID || outTaxID>0){sk.taxID=outTaxID;}
-			if(defaultParams.printSSU()){sk.loadSSU();}
-			
-			if(outSpid>0){sk.spid=outSpid;}
-			if(outImgID>0){sk.imgID=outImgID;}
-			if(outTaxName!=null){sk.setTaxName(outTaxName);}
-			if(outFname!=null){sk.setFname(outFname);}
-			if(outName0!=null){sk.setName0(outName0);}
-			sk.setMeta(outMeta);
-			
-			if(bb.length==0){
-				bb.append(defaultParams.toString(chunks));
-				chunks++;
-			}
-			sk.toBytes(bb);
-			cntr++;
-			if(cntr>=SEND_BUFFER_MAX_SKETCHES || bb.length>SEND_BUFFER_MAX_BYTES){ //Don't allow too much data in a single transaction
-				if(verbose){outstream.println("Sending:\n"+bb);}
-//				outstream.println(cntr+", "+bb.length);
-				
-				byte[] message=bb.toBytes();
-				bb.clear();
-				try {
-//					outstream.println("Sending to "+address+"\n"+message+"\n"); //123
-					StringNum result=ServerTools.sendAndReceive(message, address);
-					if(!ServerTools.suppressErrors && (result.n<200 || result.n>299)){
-						System.err.println("ERROR: Server returned code "+result.n+" and this message:\n"+result.s);
-						KillSwitch.kill();
-					}
-					errorState|=checkForError(result.s);
-					tsw.print(result.s);
-				} catch (Exception e) {
-					// TODO Auto-generated catch block
-					e.printStackTrace();
-				}
-				cntr=0;
-			}
-		}
-		
-		if(bb.length>0){
-			if(verbose){outstream.println("Sending:\n"+bb);}
-			byte[] message=bb.toBytes();
-			bb.clear();
-			try {
-				StringNum result=ServerTools.sendAndReceive(message, address);
-				if(!ServerTools.suppressErrors && (result.n<200 || result.n>299)){
-					System.err.println("ERROR: Server returned code "+result.n+" and this message:\n"+result.s);
-					KillSwitch.kill();
-				}
-				errorState|=checkForError(result.s);
-				tsw.print(result.s);
-			} catch (Exception e) {
-				// TODO Auto-generated catch block
-				e.printStackTrace();
-			}
-		}
-		if(!silent){tsw.println();}
-		tsw.poison();
-		
-//		outstream.println("sending "+bb.toString());
-		
-		if(outSketch!=null){
-			ByteStreamWriter bsw=new ByteStreamWriter(outSketch, overwrite, append, true, FileFormat.SKETCH);
-			bsw.start();
-			for(Sketch sk : inSketches){
-				sk.toBytes(bb);
-				bsw.print(bb);
-				bb.clear();
-			}
-			bsw.poisonAndWait();
-			errorState|=bsw.errorState;
-		}
-		
-		tsw.waitForFinish();
-		errorState|=tsw.errorState;
-		
-		t.stop();
-//		outstream.println("\nRan "+(inSketches.size()*refSketches.size())+" comparisons in \t"+t);
-		ttotal.stop();
-		if(!silent){outstream.println("Total Time: \t"+ttotal);}
-	}
 	
-
 	private void processRemote(Timer t){
 		Timer ttotal=new Timer();
 		
@@ -573,16 +454,93 @@ public class SendSketch extends SketchObject {
 		if(!silent){outstream.println("Total Time: \t"+ttotal);}
 	}
 	
-	/** For programmatic use */
-	public static String sendSketch(Sketch sk, String address, int format, int chunkNum){
-		address=toAddress(address);
-		ByteBuilder bb=new ByteBuilder();
 
+	public static ArrayList<JsonObject> sendSketches(ArrayList<Sketch> inSketches, String address, DisplayParams params){
+		address=toAddress(address);
+		final int numLoaded=(inSketches.size());
+		assert(numLoaded<=MAX_ALLOWED_SKETCHES) : "\nSendSketch is configured to send at most "+MAX_ALLOWED_SKETCHES+" to prevent overwhelming the server.\n"
+				+ "If you need to compare more than that, please use CompareSketch locally instead.\n"
+				+ "References can be downloaded at http://portal.nersc.gov/dna/microbial/assembly/bushnell/\n";
+		
+		int SEND_BUFFER_MAX_BYTES=8000000;
+		int SEND_BUFFER_MAX_SKETCHES=400;
+		boolean errorState=false;
+		
+		ByteBuilder bb=new ByteBuilder();
+		ArrayList<JsonObject> output=new ArrayList<JsonObject>(numLoaded);
+		JsonParser jp=new JsonParser();
+		
+		int sketchesThisChunk=0;
+		int chunkNum=0;
+		boolean firstBlock=true; //Set to false after printing has started
+		final Sketch lastSketch=Tools.getLast(inSketches); //Last input sketch to process
+		for(Sketch sk : inSketches){
+			if(bb.length==0){
+				bb.append(params.toString(chunkNum));
+				chunkNum++;
+			}
+			sk.toBytes(bb);//This does not handle null sketches
+			sketchesThisChunk++;
+			if(sketchesThisChunk>=SEND_BUFFER_MAX_SKETCHES || bb.length>SEND_BUFFER_MAX_BYTES || sk==lastSketch){ //Don't allow too much data in a single transaction
+				if(verbose){System.err.println("Sending:\n"+bb);}
+//				outstream.println(cntr+", "+bb.length);
+				
+				byte[] message=bb.toBytes();
+				bb.clear();
+				Object[] array=null;
+				for(int i=0; i<10 && (array==null || array.length<sketchesThisChunk); i++) {
+					String result=null;
+					try {
+						StringNum sn=ServerTools.sendAndReceive(message, address);
+						if(sn.n<200 || sn.n>299){
+							if(ServerTools.suppressErrors || i<9) {
+								System.err.println("Unexpected server return code "+sn.n+"; retrying...");
+								Tools.sleep(500*i);
+								continue;
+							}
+							System.err.println("ERROR: Server returned code "+sn.n+" and this message:\n"+sn.s);
+							KillSwitch.kill();
+						}
+						result=sn.s;
+						errorState|=checkForError(result);
+//						System.err.println("\nChunk "+chunkNum+":\n"+result);
+						
+						if(sketchesThisChunk>1) {array=jp.parseJsonArray(result);}
+						else {array=new Object[] {jp.parseJsonObject(result)};}
+						
+					} catch (Exception e) {
+						// TODO Auto-generated catch block
+						e.printStackTrace();
+					}
+				}
+				assert(array.length==sketchesThisChunk);
+				for(Object o : array) {
+					JsonObject jo=(JsonObject)o;
+					output.add(jo);
+				}
+				sketchesThisChunk=0;
+			}
+		}
+		
+		return output;
+	}
+	
+	@Deprecated
+	public static String sendSketch(Sketch sk, String address, int format, int chunkNum){
 		DisplayParams params=defaultParams;
 		if(format>=0){
-			new DisplayParams();
+			params=new DisplayParams();
 			params.format=format;
 		}
+		return sendSketch(sk, address, params, chunkNum);
+	}
+	
+	/** For programmatic use */
+	public static String sendSketch(Sketch sk, String address, 
+			DisplayParams params, int chunkNum){
+		address=toAddress(address);
+		ByteBuilder bb=new ByteBuilder();
+		
 		if(bb.length==0){bb.append(params.toString(chunkNum));}
 		sk.toBytes(bb);
 
