@@ -2276,34 +2276,31 @@ public class SamLine implements Serializable {
 		final int buflen=Tools.max(rnameLen(), (rnext==null ? 1 : rnext.length), (seq==null ? 1 : seq.length), (qual==null ? 1 : qual.length));
 		
 		if(bb==null){bb=new ByteBuilder(textLength()+4);}
-		if(qname==null){bb.append('*').append('\t');}else{bb.append(qname).append('\t');}
-		bb.append(flag).append('\t');
+		if(qname==null){bb.append('*').tab();}else{bb.append(qname).tab();}
+		bb.append(flag).tab();
 		if(RNAME_AS_BYTES){
 			assert(!(rname==null && rnameS!=null));
-			appendTo(bb, rname).append('\t');
+			appendTo(bb, rname).tab();
 		}else{
 			assert(!(rname!=null && rnameS==null)) : RNAME_AS_BYTES+", "+rname+", "+rnameS;
-			appendTo(bb, rnameS).append('\t');
+			appendTo(bb, rnameS).tab();
 		}
-		bb.append(pos).append('\t');
-		bb.append(mapq).append('\t');
-		if(cigar==null){bb.append('*').append('\t');}else{bb.append(cigar).append('\t');}
-		appendTo(bb, rnext).append('\t');
-		bb.append(pnext).append('\t');
-		bb.append(tlen).append('\t');
+		bb.append(pos).tab();
+		bb.append(mapq).tab();
+		if(cigar==null){bb.append('*');}
+		else{bb.append(cigar);}
+		bb.tab();
+		appendTo(bb, rnext).tab();
+		bb.append(pnext).tab();
+		bb.append(tlen).tab();
 		
 		if(mapped() && strand()==Shared.MINUS){
-			appendReverseComplemented(bb, seq).append('\t');
+			appendReverseComplemented(bb, seq).tab();
 			appendQualReversed(bb, qual);
 		}else{
-			appendTo(bb, seq).append('\t');
+			appendTo(bb, seq).tab();
 			appendQual(bb, qual);
 		}
-
-//		assert(seq.getClass()==String.class);
-//		assert(qual.getClass()==String.class);
-//		sb.append(seq).append('\t');
-//		sb.append(qual);
 		
 		if(optional!=null){
 			for(String s : optional){
