@@ -486,7 +486,7 @@ public final class IntLongHashMap{
 
 	public long[] values() {return values;}
 
-	public long invalid() {return invalid;}
+	public int invalid() {return invalid;}
 	
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
